@@ -137,7 +137,7 @@ use warnings;
 
 use base qw{ Astro::Coord::ECI::TLE };
 
-our $VERSION = '0.104_03';
+our $VERSION = '0.104_04';
 
 use Astro::Coord::ECI::Utils 0.091 qw{:all};
 use Carp;
@@ -1681,7 +1681,7 @@ sub _set_operational_status {
 # All Iridium Classic satellites.
 #
 # Generated by Astro::SpaceTrack tools/all_iridium_classic -tle -indent=0
-# on Sun Sep  2 12:56:50 2018 GMT
+# on Sun Sep  2 23:31:25 2018 GMT
 
 __PACKAGE__->status( clear => 'iridium' );
 __PACKAGE__->status( add => 24792, iridium => 'D', 'Iridium 8', 'Decayed 2017-11-24' );
@@ -1690,7 +1690,7 @@ __PACKAGE__->status( add => 24794, iridium => 'D', 'Iridium 6', 'Decayed 2017-12
 __PACKAGE__->status( add => 24795, iridium => '-', 'Iridium 5', 'Tumbling' );
 __PACKAGE__->status( add => 24796, iridium => '-', 'Iridium 4', 'Tumbling' );
 __PACKAGE__->status( add => 24836, iridium => '-', 'Iridium 914', 'Tumbling' );
-__PACKAGE__->status( add => 24837, iridium => '-', 'Iridium 12', 'Tumbling' );
+__PACKAGE__->status( add => 24837, iridium => 'D', 'Iridium 12', 'Decayed 2018-09-02' );
 __PACKAGE__->status( add => 24838, iridium => 'D', 'Iridium 9', 'Decayed 2003-03-11' );
 __PACKAGE__->status( add => 24839, iridium => '+', 'Iridium 10', '' );
 __PACKAGE__->status( add => 24840, iridium => 'D', 'Iridium 13', 'Decayed 2018-04-29' );
@@ -1785,8 +1785,8 @@ __PACKAGE__->status( add => 27451, iridium => 'D', 'Iridium 98', 'Decayed 2018-0
 # Summary:
 # Operational [+]: 14
 #       Spare [S]: 14
-#    Tumbling [-]: 35
-#     Decayed [D]: 34
+#    Tumbling [-]: 34
+#     Decayed [D]: 35
 
 1;
 
